Changelog
=========

1.0.0 (2022-05-09)
------------------

- Initial release: add-annotation-overlay-(ic/is/od), image-viewer-(ic/is/od)
- Received to-annotation-overlay-od from wai.annotations.imgstats

